Changelog
=========

0.2
-----

- Fix removal of base directory upon uninstall. (#1)

- Update files on every buildout run, rather loading them once.

0.1.1
-----

- Fixed documentation so it displays correctly on PyPI
  [Anshuman Bhaduri]

0.1
---

- Created initial recipe
  [Anshuman Bhaduri]
